@@ -6,7 +6,7 @@ package Dist::Iller::Config::Author::CSSON;
 
 # ABSTRACT: Dist::Iller config
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.0307';
+our $VERSION = '0.0308';
 
 use Moose;
 use namespace::autoclean;
@@ -157,8 +157,8 @@ Dist::Iller::Config::Author::CSSON - Dist::Iller config
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON"><img src="https://api.travis-ci.org/Csson/p5-Dist-Iller-Config-Author-CSSON.svg?branch=master" alt="Travis status" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Dist-Iller-Config-Author-CSSON-0.0307"><img src="https://badgedepot.code301.com/badge/kwalitee/Dist-Iller-Config-Author-CSSON/0.0307" alt="Distribution kwalitee" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Dist-Iller-Config-Author-CSSON%200.0307"><img src="https://badgedepot.code301.com/badge/cpantesters/Dist-Iller-Config-Author-CSSON/0.0307" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Dist-Iller-Config-Author-CSSON-0.0308"><img src="https://badgedepot.code301.com/badge/kwalitee/Dist-Iller-Config-Author-CSSON/0.0308" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Dist-Iller-Config-Author-CSSON%200.0308"><img src="https://badgedepot.code301.com/badge/cpantesters/Dist-Iller-Config-Author-CSSON/0.0308" alt="CPAN Testers result" /></a>
 <img src="https://img.shields.io/badge/coverage-42.7%-red.svg" alt="coverage 42.7%" />
 </p>
 
@@ -166,7 +166,7 @@ Dist::Iller::Config::Author::CSSON - Dist::Iller config
 
 =head1 VERSION
 
-Version 0.0307, released 2016-02-18.
+Version 0.0308, released 2016-02-18.
 
 
 
@@ -546,36 +546,6 @@ Dist::Iller::Config::Author::Csson is a L<Dist::Iller> configuration. The plugin
 
 =end markdown
 
-=head2 distribution_name
-
-=begin HTML
-
-<table cellpadding="0" cellspacing="0">
-<tr>
-    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Str">Str</a></td>
-    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional</td>
-    <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td>
-</tr>
-</table>
-
-<p></p>
-
-=end HTML
-
-=begin markdown
-
-<table cellpadding="0" cellspacing="0">
-<tr>
-    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Str">Str</a></td>
-    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional</td>
-    <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td>
-</tr>
-</table>
-
-<p></p>
-
-=end markdown
-
 =head1 ENVIRONMENT VARIABLES
 
 =head2 FAKE_RELEASE
@@ -584,7 +554,7 @@ If set to a true value this will include [FakeRelease] and remove either [Upload
 
 =head1 SOURCE
 
-L<https://github.com/Csson/p5-Dist-Iller-Config-Author-CSSON>
+Source repository is at L<https://github.com/Csson/p5-Dist-Iller-Config-Author-CSSON>.
 
 =head1 HOMEPAGE
 
