@@ -6,7 +6,7 @@ package Dist::Iller::Config::Author::CSSON::MapMetro;
 
 # ABSTRACT: Dist::Iller config for Map::Metro
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.0307';
+our $VERSION = '0.0308';
 
 use Moose;
 extends 'Dist::Iller::Config::Author::CSSON';
@@ -37,7 +37,7 @@ Dist::Iller::Config::Author::CSSON::MapMetro - Dist::Iller config for Map::Metro
 
 =head1 VERSION
 
-Version 0.0307, released 2016-02-18.
+Version 0.0308, released 2016-02-18.
 
 
 
@@ -52,7 +52,7 @@ Dist::Iller::Config::Author::Csson::MapMetro is a L<Dist::Iller> configuration.
 
 =head1 SOURCE
 
-L<https://github.com/Csson/p5-Dist-Iller-Config-Author-CSSON>
+Source repository is at L<https://github.com/Csson/p5-Dist-Iller-Config-Author-CSSON>.
 
 =head1 HOMEPAGE
 
